import { Chain, LayoutToType, Network, Platform, PlatformToChains } from "@wormhole-foundation/sdk-base";
import { AccountAddress, ChainAddress } from "../address";
import { CircleMessageId } from "../attestation";
import { TokenId } from "../types";
import { UnsignedTransaction } from "../unsignedTransaction";
import "../payloads/automaticCircleBridge";
import { circleMessageLayout } from "../payloads/circleBridge";
export type CircleMessage = LayoutToType<typeof circleMessageLayout>;
export declare const deserializeCircleMessage: (data: Uint8Array) => [CircleMessage, string];
export declare const serializeCircleMessage: (msg: CircleMessage) => Uint8Array;
export type CircleTransferMessage = {
    from: ChainAddress;
    to: ChainAddress;
    token: TokenId;
    amount: bigint;
    message: CircleMessage;
    id: CircleMessageId;
};
export type CircleTransferDetails = {
    amount: bigint;
    from: ChainAddress;
    to: ChainAddress;
    automatic?: boolean;
    payload?: Uint8Array;
    nativeGas?: bigint;
};
export declare function isCircleTransferDetails(thing: any): thing is CircleTransferDetails;
export interface CircleBridge<N extends Network, P extends Platform, C extends PlatformToChains<P>> {
    redeem(sender: AccountAddress<C>, message: CircleMessage, attestation: string): AsyncGenerator<UnsignedTransaction<N, C>>;
    transfer(sender: AccountAddress<C>, recipient: ChainAddress, amount: bigint): AsyncGenerator<UnsignedTransaction<N, C>>;
    parseTransactionDetails(txid: string): Promise<CircleTransferMessage>;
}
export interface AutomaticCircleBridge<N extends Network, P extends Platform, C extends Chain = PlatformToChains<P>> {
    getRelayerFee(destination: Chain): Promise<bigint>;
    transfer(sender: AccountAddress<C>, recipient: ChainAddress, amount: bigint, nativeGas?: bigint): AsyncGenerator<UnsignedTransaction<N, C>>;
}
//# sourceMappingURL=cctp.d.ts.map